"""An on-screen sensor for showing the number of mines close to you"""

import random

import serge.actor
import serge.blocks.visualblocks

from theme import G, theme


class MetalSensor(serge.actor.Actor):
    """A sensor to show different levels"""

    def __init__(self, tag, name):
        """Initialise the sensor"""
        super(MetalSensor, self).__init__(tag, name)
        #
        self.visual = serge.blocks.visualblocks.BlockedProgressBar(
            G('sensor-size'), G('sensor-block-size'), True,
            G('sensor-blocks'), use_back_colour=True
        )
        self.randomness = G('sensor-randomness')
        self.decay = G('sensor-decay')
        #
        self.value = 0.0

    def setValue(self, value):
        """Set the sensor value"""
        self.value = value

    def getValue(self):
        """Return the sensor value"""
        return self.value

    def updateActor(self, interval, world):
        """Update the actor"""
        super(MetalSensor, self).updateActor(interval, world)
        #
        value = self.getValue()
        new_value = max(0.0, value + random.randrange(-self.randomness, +self.randomness))
        self.setValue(new_value)
        #
        display_value = self.visual.getValue()
        relaxation_factor = interval / 1000.0 * self.decay
        actual_value = relaxation_factor * display_value + (1.0 - relaxation_factor) * new_value
        self.visual.setValue(actual_value)