"""Local serialization"""

import time
import getpass

import serge.blocks.storage

STORAGE = serge.blocks.storage.Storage('minefield.db')


def initStorage():
    """Initialise the storage system"""
    #
    # Create the tables
    STORAGE.addTable(
        'users',
        'create table users (name text, difficulty text, accessed real, games int)')
    #
    # And default data
    STORAGE.addDefaultRows('users', 'name', [(getpass.getuser(), 'Intermediate', time.time(), 0)])
    STORAGE.save()


class User(object):

    def __init__(self, name, difficulty, games):
        """Initialise the user"""
        self.name = name
        self.difficulty = difficulty
        self.games = games

    @classmethod
    def getLastUser(cls):
        """Return the latest user"""
        result = STORAGE.get('select name, difficulty, games from users order by accessed desc')
        return cls(*result[0])

    @classmethod
    def updateUser(cls, username, game):
        """Update a user"""
        STORAGE.get('delete from users where name = ?', [username])
        STORAGE.get('insert into users values(?, ?, ?, 1)', [username, game, time.time()])
        STORAGE.save()