"""Our main visual theme"""

import collections
import serge.blocks.themes

W, H = 800, 600

C_FLAGS_COLOUR = (237, 154, 36, 255)
C_FLAGS_OFF_COLOUR = (237, 154, 36, 50)

theme = serge.blocks.themes.Manager()
theme.load({
    'main': ('', {
    
    # Main properties
    'screen-height': H,
    'screen-width': W,
    'screen-title': 'Minefield',
    'screen-icon-filename': 'icon.png',
    'screenshot-size': (0, 0, W, H),

    # Overlay properties
    'overlay-position': (W / 2, H / 2),

    # Mute button
    'mute-button-alpha': 1.0,
    'mute-button-position': (52, 138),
    'pre-stop-pause': 0.5,
    
    # FPS display
    'fps-x': 50,
    'fps-y': H-30,
    'fps-colour': (255, 255, 0),
    'fps-size': 12,

    # Field settings
    'mine-probability': 0.2,
    'field-x-size': 30,
    'field-y-size': 20,
    'field-cell-size': 22,
    'field-position': (W / 2 - 20, H / 2 + 20),
    'field-cell-text-colour': (0, 0, 0),
    'field-cell-highlight-colour': (255, 0, 0, 100),

    # Triggering
    'trigger-timeout': 5,

    # Clock properties
    'clock-font-size': 30,
    'clock-font': 'terminal',
    'clock-justify': 'left',
    'clock-colour': (237, 154, 36),
    'clock-position': (540, 63),
    'clock-digits-position': (699, 74),

    # Oscilloscope properties
    'scope-size': (100, 67),
    'scope-position': (W / 2, 90),
    'scope-colour': (0, 255, 0, 255),
    'scope-x-points': 100,
    'scope-x-width': 40,
    'scope-relaxation': 15.0,
    'scope-angle-jitter': 10.0,
    'scope-amplitude-jitter': 2.0,
    'scope-y-offset': -2.0,

    # Flags properties
    'flags-font-size': 30,
    'flags-font': 'terminal',
    'flags-justify': 'left',
    'flags-colour': C_FLAGS_COLOUR,
    'flags-position': (185, 63),
    'flags-digits-position': (120, 74),

    # Flag "shot counter" widget

    'flag-counter-blocks': [
        (i + 1, C_FLAGS_COLOUR, C_FLAGS_OFF_COLOUR) for i in range(10)
    ],
    'flag-counter-position': (242, 100),
    'flag-counter-size': (110, 30),
    'flag-counter-block-size': (7, 3),
    'flag-counter-decay-time': 1.0,
    'flag-counter-max': 10,

    # Success properties
    'success-font-size': 56,
    'success-font': 'terminal',
    'success-justify': 'center',
    'success-colour': (0, 255, 0),
    'success-position': (400, 250),

    # Scores properties
    'scores-font-size': 20,
    'scores-font': 'terminal',
    'scores-justify': 'center',
    'scores-colour': (0, 255, 0),
    'scores-position': (154, 433),
    'high-score-start-colour': (0, 255, 0, 255),
    'high-score-end-colour': (0, 255, 0, 100),
    'high-score-duration': 500,
    'high-score-fraction': 0.8,

    # Restart properties
    'restart-font-size': 20,
    'restart-font': 'terminal',
    'restart-justify': 'center',
    'restart-colour': (0, 255, 0),
    'restart-position': (145, 503),

    # Credits properties
    'credits-font-size': 20,
    'credits-font': 'terminal',
    'credits-justify': 'center',
    'credits-colour': (0, 255, 0),
    'credits-position': (130, 468),

    # Difficulty levels
    'difficulties': collections.OrderedDict(
        [
            #('Test', (9, 9, 2, 50, 560)),
            # Name width,  height,  bombs, triggers
            ('Easy', (9, 9, 10, 5)),
            ('Medium', (16, 16, 40, 20)),
            ('Hard', (26, 16, 99, 35)),
        ]),

    # Hardware buttons
    'hardware-difficulty-buttons': [
        ('Easy', (140, 558), ('yellow-button', 'red-button'), False),
        ('Medium', (240, 561), ('yellow-button', 'red-button'), False),
        ('Hard', (340, 563), ('yellow-button', 'red-button'), False),
    ],

    # Navigation buttons
    'navigation-buttons': [
        ('on-off-button', (766, 129), ('on-off-button', 'on-off-button'), False),
        ('high-scores', (49, 433), ('green-left-on-button', 'green-left-off-button'), False),
        ('new-game', (55, 503), ('green-left-on-button', 'green-left-off-button'), False),
        ('submit', (50, 468), ('green-left-on-button', 'green-left-off-button'), False),
    ],

    # Game mode buttons
    'game-mode-buttons': [
        ('Classic', (W - 140 - 150, 561), ('yellow-button', 'red-button'), False),
        ('Enhanced', (W - 140, 558), ('yellow-button', 'red-button'), False),
    ],

    # Difficulty menu properties
    'menu-width': 300,
    'menu-on-colour': (255, 255, 255, 0),
    'menu-off-colour': (255, 0, 0, 0),
    'menu-font-colour': (255, 255, 255),
    'menu-font-size': 20,
    'menu-position': (240, 545),
    'menu-item-width': 100,
    'menu-item-height': 40,
    'menu-default': 'Medium',

    # Mode menu properties
    'mode-width': 300,
    'mode-on-colour': (255, 255, 255, 0),
    'mode-off-colour': (255, 0, 0, 0),
    'mode-font-colour': (255, 255, 255),
    'mode-font-size': 20,
    'mode-position': (W - 140 - 75, 545),
    'mode-item-width': 100,
    'mode-item-height': 40,
    'mode-default': 'Enhanced',

    # Enhanced mode properties
    'mode-enhanced-show-numbers': True,
    'mode-enhanced-grouping-factor': 3.0,

    # Confirm properties
    'confirm-back-colour': (181, 92, 19, 230),
    'confirm-front-colour': (255, 255, 255),
    'confirm-font-size': 48,
    'confirm-height': 200,

    # Button zoom
    'button-zoom-start': 1.0,
    'button-zoom-end': 1.1,
    'button-zoom-duration': 1.0,

    # Sensor properties
    'sensor-size': (20, 200),
    'sensor-block-size': (20, 10),
    'sensor-blocks': [
        (10.0, (0, 255, 0, 255), (0, 255, 0, 100)),
        (20.0, (0, 255, 0, 255), (0, 255, 0, 100)),
        (30.0, (0, 255, 0, 255), (0, 255, 0, 100)),
        (40.0, (0, 255, 0, 255), (0, 255, 0, 100)),
        (50.0, (255, 255, 0, 255), (255, 255, 0, 100)),
        (60.0, (255, 255, 0, 255), (255, 255, 0, 100)),
        (70.0, (255, 255, 0, 255), (255, 255, 0, 100)),
        (80.0, (255, 0, 0, 255), (255, 0, 0, 100)),
        (90.0, (255, 0, 0, 255), (255, 0, 0, 100)),
        (100.0, (255, 0, 0, 255), (255, 0, 0, 100)),
    ],
    'sensor-position': (700, 300),
    'sensor-randomness': 20.0,
    'sensor-decay': 15.0,
    'sensor-explosion': 30.0,

    }),

    
    'start-screen': ('main', {
        # Logo and title
        'logo-position': (W/2, 140),
        'title': 'minefield',
        'title-position': (W/2, 300),
        'title-colour': (255, 255, 255, 255),
        'title-font-size': 36,
        # Version text
        'version-position': (W/2, H-10),
        'version-colour': (50, 50, 50),
        'version-font-size': 12,
        # Start button
        'start-position': (W/2, H-120),
        'start-colour': (255, 255, 0, 255),
        'start-font-size': 48,
        # Help button
        'help-position': (W-100, H-40),
        'help-colour': (0, 255, 0, 255),
        'help-font-size': 24,
        # Credits button
        'credits-position': (100, H-40),
        'credits-colour': (0, 255, 0, 255),
        'credits-font-size': 24,    
        # Achievements button
        'achievements-position': (W/2, H-40),
        'achievements-colour': (0, 255, 0, 255),
        'achievements-font-size': 24,    
    }),

    'sub-screen': ('start-screen', {
        # Logo and title
        'logo-position': (W/2-50, 40),
        'title-position': (W/2+50, 40),
        'title-colour': (255, 255, 255, 255),
        'title-font-size': 36,
        # Back button
        'back-colour': (255, 255, 0, 255),
        'back-font-size': 24,
    }),
    'help-screen': ('sub-screen', {
        # Help text
        'text-position': (W/2, H/2),
    }),
    'high-score-screen': ('sub-screen', {
        # App
        'app-url': 'http://perpetualpyramidhighscores.appspot.com',
        #'app-url': 'http://localhost:9000',
        'app-name': 'Minefield',
        # Your score properties
        'score-font-size': 30,
        'score-font': 'terminal',
        'score-justify': 'left',
        'score-colour': (237, 154, 36),
        'score-position': (410, 63),
        # Your best score properties
        'best-score-font-size': 18,
        'best-score-font': 'terminal',
        'best-score-justify': 'center',
        'best-score-colour': (255, 255, 255),
        'best-score-position': (W / 2, 450),
        # Update
        'update-font-size': 16,
        'update-font': 'terminal',
        'update-justify': 'center',
        'update-colour': (0, 255, 0),
        'update-position': (400, 200),
        # Clear
        'clear-font-size': 20,
        'clear-font': 'terminal',
        'clear-justify': 'center',
        'clear-colour': (0, 255, 0),
        'clear-position': (150, 503),
        # Submit
        'submit-font-size': 20,
        'submit-font': 'terminal',
        'submit-justify': 'center',
        'submit-colour': (0, 255, 0),
        'submit-position': (158, 468),
        # Status
        'status-font-size': 12,
        'status-font': 'terminal',
        'status-justify': 'center',
        'status-colour': (255, 255, 255),
        'status-position': (400, 175),
        # Name
        'name-font-size': 36,
        'name-font': 'terminal',
        'name-justify': 'center',
        'name-colour': (0, 255, 0),
        'name-position': (150, 130),
        # Entry
        'entry-width': 420,
        'entry-height': 40,
        'entry-colour': (0, 255, 0),
        'entry-fill-colour': (0, 255, 0, 50),
        'entry-stroke-colour': (0, 255, 0),
        'entry-stroke-width': 1,
        'entry-size': 36,
        'entry-position': (460, 130),
        # Back button
        'back-position': (100, 433),
        'back-colour': (0, 255, 0, 255),
        'back-font-size': 20,
        # Table
        'table-layout-width': 800,
        'table-layout-height': 300,
        'table-layout-position': (400, 210),
        'max-scores': 5,
        'table-width': 150,
        'table-item-height': 30,
        'table-title-colour': (255, 255, 255),
        'table-title-size': 22,
        'table-title-font': 'terminal',
        'hs-font-size': 16,
        'hs-font-name': 'terminal',
        'hs-font-colour': (0, 255, 0),
        'hs-font-player-colour': (255, 255, 0),
        # Help text
        'text-position': (W/2, H/2),
    }),
    'credits-screen': ('sub-screen', {
        # Logo
        'logo-position': (W/2, 140),
        # Version
        'version-font-size': 30,
        'version-font': 'terminal',
        'version-justify': 'left',
        'version-colour': (237, 154, 36),
        'version-position': (475, 63),
        # Author
        'author-title-colour': (0, 220, 220),
        'author-title-font-size': 24,
        'author-title-position': (W/2, 210),
        'author-colour': (255, 255, 0),
        'author-font-size': 32,
        'author-position': (W/2, 250),
        'url-colour': (255, 0, 0),
        'url-font-size': 14,
        'url-position': (W/2, 270),
        # Music
        'music-title1-colour': (0, 220, 220),
        'music-title1-font-size': 20,
        'music-title1-position': (W/2, 220),
        'music-title2-colour': (0, 220, 220),
        'music-title2-font-size': 18,
        'music-title2-position': (W/2, 240),
        'music-colour': (255, 255, 0),
        'music-font-size': 16,
        'music-position': (W/2, 260),
        # Sound
        'sound-title1-colour': (0, 220, 220),
        'sound-title1-font-size': 20,
        'sound-title1-position': (W/2, 340),
        'sound-title2-colour': (0, 220, 220),
        'sound-title2-font-size': 18,
        'sound-title2-position': (W/2, 360),
        # Built using        
        'built-title-colour': (0, 220, 220),
        'built-title-font-size': 20,
        'built-title-position': (W/3, 420),
        'built-colour': (255, 255, 0),
        'built-font-size': 16,
        'built-position': (W/3, 440),
        # Engine
        'engine-title-colour': (0, 220, 220),
        'engine-title-font-size': 20,
        'engine-title-position': (W/3, 480),
        'engine-colour': (255, 255, 0),
        'engine-font-size': 16,
        'engine-position': (W/3, 500),
        # Engine version
        'engine-version-colour': (75, 75, 0),
        'engine-version-font-size': 10,
        'engine-version-position': (W/3, 520),
        # Fonts
        'font-title1-colour': (0, 220, 220),
        'font-title1-font-size': 20,
        'font-title1-position': (W*2/3, 420),
        'font-title2-colour': (0, 220, 220),
        'font-title2-font-size': 18,
        'font-title2-position': (W*2/3, 440),
        'font-colour': (255, 255, 0),
        'font-font-size': 16,
        'font-position': (W*2/3, 460),
        # Back button
        'back-position': (110, 468),
        'back-colour': (0, 255, 0, 255),
        'back-font-size': 20,

    }),
    
    'achievements': ('main', {
        # Properties of the achievements system
        'banner-duration': 5,
        'banner-position': (175, 525),
        'banner-size': (300, 50),
        'banner-backcolour': (0, 0, 0, 50),
        'banner-font-colour': (255, 255, 0, 255),
        'banner-name-size': 14,
        'banner-description-size': 8,
        'banner-name-position': (-100, -18),
        'banner-description-position': (-100, 0),
        'banner-font-name': 'DEFAULT',
        'banner-graphic-position': (-125, 0),
        
        'time-colour': (255, 255, 255, 100),
        'time-size': 10,
        'time-position': (-100, 24),
        
        'logo-position': (400, 50),
        'screen-background-sprite': None,
        'screen-background-position': (400, 300),
        'grid-size': (2, 5),
        'grid-width': 800,
        'grid-height': 400,
        'grid-position': (400, 320),
        
        'back-colour': (255, 255, 255, 255),
        'back-font-size': 20,
        'back-font-name': 'DEFAULT',
        'back-position': (400, 560),
        'back-sound': 'click',
    }),

    '__default__': 'main',

})

G = theme.getProperty
